@@ -13,7 +13,7 @@ package Lemonldap::NG::Manager::Notifications;
 
 use strict;
 use Lemonldap::NG::Handler::CGI qw(:globalStorage :locationRules);
-use Lemonldap::NG::Common::Notification;
+use Lemonldap::NG::Portal::Notification;
 use Lemonldap::NG::Common::Conf;              #link protected conf Configuration
 use Lemonldap::NG::Common::Conf::Constants;   #inherits
 require Lemonldap::NG::Manager::_i18n;        #inherits
@@ -22,7 +22,7 @@ use utf8;
 our $whatToTrace;
 *whatToTrace = \$Lemonldap::NG::Handler::_CGI::whatToTrace;
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.2.2';
 
 our @ISA = qw(
   Lemonldap::NG::Handler::CGI
@@ -99,8 +99,8 @@ sub new {
     }
 
     $tmp->{p}            = $self;
-    $self->{notifObject} = Lemonldap::NG::Common::Notification->new($tmp);
-    $class->abort($Lemonldap::NG::Common::Notification::msg)
+    $self->{notifObject} = Lemonldap::NG::Portal::Notification->new($tmp);
+    $class->abort($Lemonldap::NG::Portal::Notification::msg)
       unless ( $self->{notifObject} );
 
     # Multi values separator
@@ -634,7 +634,7 @@ notifications
   our $cgi ||= Lemonldap::NG::Manager::Notifications->new({
         localStorage        => "Cache::FileCache",
         localStorageOptions => {
-            'namespace'          => 'lemonldap-ng-config',
+            'namespace'          => 'lemonldap-ng',
             'default_expires_in' => 600,
             'directory_umask'    => '007',
             'cache_root'         => '/tmp',
@@ -645,6 +645,8 @@ notifications
           type=>'File',
           dirName=>"/tmp/",
         },
+        # Force the use of X-FORWARDED-FOR for IP
+        useXForwardedForIP => 1,
         # Optionnal
         protection    => 'rule: $uid eq "admin"',
         # Or to use rules from manager
@@ -668,15 +670,53 @@ L<Lemonldap::NG::Handler::CGI>, L<Lemonldap::NG::Manager>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
-Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011 by Xavier Guimard, Clement Oudot
+=over
+
+=item Copyright (C) 2013 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Sandro Cazzaniga, E<lt>cazzaniga.sandro@gmail.comE<gt>
+
+=item Copyright (C) 2012, 2013 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
